#!/bin/sh
#-----------------------------------------------------------------------
#
# Tivoli Enterprise Data Warehouse, v 1.1.1 
# (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
#
#-----------------------------------------------------------------------
# File Information: src/install/bin/twh_create_cfg_file.sh, twh_core, twh_1.1_fp1
#
# Revision: 1.9
#
# Date: 6/14/02 15:59:51
#-----------------------------------------------------------------------
#

PROGRAM=$0
config_file="$1"



TWH_CONFIG_FILE="$TWH_TOPDIR/install/logs/twh_core_install.cfg.done"
TWH_CORE_COMP_LIST="$TWH_TOPDIR/install/logs/twh_core_comp_list.cfg"

BYPASS_PASSWORD_REQUIRED=1
export BYPASS_PASSWORD_REQUIRED
TWH_CORE_PATCH_CONTEXT=1
export TWH_CORE_PATCH_CONTEXT

# Pulls in the generic shared routines
# Note return codes 3-70 reserved for the gen routines
include_gen_routines()
{
# Bug on NT - fix the path back to be unix type path
gen_file_and_path=`echo $PROGRAM | sed 's/\\\\/\//g' `

gen_path=`dirname "$gen_file_and_path" `

# Confirm file (twh_gen_routines must be in same directory)
if [ ! -r "$gen_path"/twh_gen_routines.sh ]; then
  echo "      (F) CDWIC0071E Could not locate the twh_gen_routines.sh file."
  exit 71
fi

# pull in the generic routines
. "$gen_path"/twh_gen_routines.sh

return 0;
}


### Main ###

# Source in information from original core install.
include_gen_routines;

gr_display_generic_header "TEDW Core Tools Patch Installer";
echo ""
echo "==> No patch config file detected, Auto-Generating for later use..."
echo ""

gr_set_interp;
if [ $UNIX_INTERP -eq 0 ]; then
  TWH_CONFIG_FILE=`echo "$TWH_CONFIG_FILE" | sed 's/\\\\/\//g' `
fi

gr_read_config_file;

# save the current directory that the script was run
curdir=`pwd`

config_file=`echo $config_file | sed 's/\\\\/\//g'`              
PATCH_MEDIA_DIR=`echo $PATCH_MEDIA_DIR | sed 's/\\\\/\//g'`
TWH_TOPDIR=`echo $TWH_TOPDIR | sed 's/\\\\/\//g'`
TMPDIR=`echo $TMPDIR | sed 's/\\\\/\//g'`

# Check to see if RPI is installed on this machine.
RPICOMPLINE=`grep TWH_RPI_COMP "$TWH_CORE_COMP_LIST" `
RPICOMP=`echo $RPICOMPLINE | sed 's/TWH_RPI_COMP=//g' | tr '[a-z]' '[A-Z]'`

echo "==> Writing config file..."


echo "# Tivoli Enterprise Data Warehouse Core Patch" > "$config_file"
echo "# Configuration File" >> "$config_file"
echo "#" >> "$config_file"
echo "# (C) COPYRIGHT TIVOLI Systems, Inc. 2002" >> "$config_file"
echo "# Unpublished Work" >> "$config_file"
echo "# All Rights Reserved" >> "$config_file"
echo "# Licensed Material - Property of TIVOLI Systems, Inc." >> "$config_file"
echo "#" >> "$config_file"
echo "###################################################################" >> "$config_file"
echo "#" >> "$config_file"
echo "# Instructions: This config file provides information needed to " >> "$config_file"
echo "# install a Tivoli Enterprise Data Warehouse Core patch. You " >> "$config_file"
echo "# must install this patch on each host within your enterprise" >> "$config_file"
echo "# that has a TEDW component on it to ensure all hosts are at " >> "$config_file"
echo "# the same patch level." >> "$config_file"
echo "#" >> "$config_file"
echo "# 1. Supply all values to the properties in the 'USER SUPPLIED" >> "$config_file"
echo "#    SECTION'." >> "$config_file"
echo "#" >> "$config_file"
echo "# 2. Ensure all properties are supplied correctly in 'AUTO-GENERATED" >> "$config_file"
echo "#    SECTION' and 'AUTO-GENERATED SECTION - SUPPORT'." >> "$config_file"
echo "#" >> "$config_file"
echo "# 3. The primary file used to Auto-generate these properties is " >> "$config_file"
echo "#    $TWH_TOPDIR/install/logs/twh_core_config.cfg.done.  Note that" >> "$config_file"
echo "#    on a single host" >> "$config_file"
echo "#    install all the DB2PASS values will be the same.  Also note that" >> "$config_file"
echo "#    for security, passwords are removed from this file after this " >> "$config_file"
echo "#    patch has been installed.  Additionally if you have problems"  >> "$config_file"
echo "#    installing this patch, you should remove these passwords if you"  >> "$config_file"
echo "#    intend on leaving this configuration file around for some time." >> "$config_file"
echo "#" >> "$config_file"
echo "# NOTES:" >> "$config_file"
echo "# 1. Do not change the values in the 'AUTO-GENERATED SECTION - SUPPORT'"  >> "$config_file"
echo "#    section unless told to do so by your support provider or not"  >> "$config_file"
echo "#    properly auto-generated." >> "$config_file"
echo "# 2. All file paths must be absolute and not relative.  Also all paths" >> "$config_file"
echo "#    must be defined in the Unix format not the Windows format.  This " >> "$config_file"
echo "#    means that c:\temp (on Windows) should be c:/temp with a slash (/)" >> "$config_file"
echo "#    for in the path, not a backslash (\) in the path.  This is the" >> "$config_file"
echo "#    case no matter what operating system you are running this program" >> "$config_file"
echo "#    on." >> "$config_file"
echo "# 3. All properties must have a supplied value and must take the form" >> "$config_file"
echo "#    of property=value exactly.  You cannot have more than one value" >> "$config_file"
echo "#    per property" >> "$config_file"
echo "# 4. Properties that have file paths as values must not include any" >> "$config_file"
echo "#    spaces (whitespace) at the end of that path." >> "$config_file"
echo "#" >> "$config_file"
echo "#" >> "$config_file"
echo "########################################################################" >> "$config_file"
echo "# " >> "$config_file"
echo "############ USER SUPPLIED SECTION #####################################" >> "$config_file"

echo "# Edit the following lines with the information specific to your" >> "$config_file"
echo "# setup. For more information on the definition of each of these tags,"  >> "$config_file"
echo "# please look at the template config file (twh_core_patcher.cfg)" >> "$config_file"
echo "# located in the 'generic/install/bin' directory of this patch" >> "$config_file"
echo "# " >> "$config_file"

if [ "$RPICOMP" = "TRUE" ]; then
    echo "PS_HOME=" >> "$config_file"
fi

echo "DB2PASS=" >> "$config_file"
echo "COPT_CTRL_DB2PASS=" >> "$config_file"
echo "COPT_CDW_DB2PASS=" >> "$config_file"
echo "COPT_MART_DB2PASS=" >> "$config_file"
echo "# " >> "$config_file"
echo "############ AUTO-GENERATED SECTION #####################################" >> "$config_file"
echo "PATCH_MEDIA_DIR=$curdir" >> "$config_file"
echo "TWH_TOPDIR=$TWH_TOPDIR" >> "$config_file"
echo "TMPDIR=$TMPDIR" >> "$config_file"
echo "DB2_INST_DIR=$DB2_INST_DIR" >> "$config_file"
echo "DB2USER=$DB2USER" >> "$config_file"
echo "COPT_CTRL_DB2HOST=$COPT_CTRL_DB2HOST" >> "$config_file"
echo "COPT_CTRL_DB2PORT=$COPT_CTRL_DB2PORT" >> "$config_file"
echo "COPT_CTRL_DB2USER=$COPT_CTRL_DB2USER" >> "$config_file"
echo "COPT_CDW_DB2HOST=$COPT_CDW_DB2HOST" >> "$config_file"
echo "COPT_CDW_DB2PORT=$COPT_CDW_DB2PORT" >> "$config_file"
echo "COPT_CDW_DB2USER=$COPT_CDW_DB2USER" >> "$config_file"
echo "COPT_MART_DB2HOST=$COPT_MART_DB2HOST" >> "$config_file"
echo "COPT_MART_DB2PORT=$COPT_MART_DB2PORT" >> "$config_file"
echo "COPT_MART_DB2USER=$COPT_MART_DB2USER" >> "$config_file"
echo "LOCAL_HOSTNAME=$LOCAL_HOSTNAME" >> "$config_file"
echo "# " >> "$config_file"
echo "############ AUTO-GENERATED SECTION - SUPPORT #####################################" >> "$config_file"
echo "TWH_CTRL_DB=TWH_MD" >> "$config_file"
echo "TWH_CDW_DB=TWH_CDW" >> "$config_file"
echo "TWH_DM_DB=TWH_MART" >> "$config_file"
echo "DB2_INSTALL_LOG=twh_ibm_db2_patch_runlog.log" >> "$config_file"
echo "TWH_VERSION=1.1.1" >> "$config_file"
echo "TWH_KEEP_TMP_FILES=false" >> "$config_file"
echo "#.done" >> "$config_file"

echo
echo "      (I) Writing config file completed."
echo "          The config file is located at $config_file"
echo
echo "      (I) The following user changeable values are set in the config file:"
echo
echo "          PATCH_MEDIA_DIR=$curdir"
echo "          TWH_TOPDIR=$TWH_TOPDIR"
echo "          TMPDIR=$TMPDIR" 
echo "          DB2_INST_DIR=$DB2_INST_DIR"

if [ "$RPICOMP" = "TRUE" ]; then
    echo "          PS_HOME="
fi

echo "          DB2USER=$DB2USER"
echo "          DB2PASS="
echo "          COPT_CTRL_DB2HOST=$COPT_CTRL_DB2HOST"
echo "          COPT_CTRL_DB2PORT=$COPT_CTRL_DB2PORT"
echo "          COPT_CTRL_DB2USER=$COPT_CTRL_DB2USER"
echo "          COPT_CTRL_DB2PASS="
echo "          COPT_CDW_DB2HOST=$COPT_CDW_DB2HOST"
echo "          COPT_CDW_DB2PORT=$COPT_CDW_DB2PORT"
echo "          COPT_CDW_DB2USER=$COPT_CDW_DB2USER"
echo "          COPT_CDW_DB2PASS="
echo "          COPT_MART_DB2HOST=$COPT_MART_DB2HOST"
echo "          COPT_MART_DB2PORT=$COPT_MART_DB2PORT"
echo "          COPT_MART_DB2USER=$COPT_MART_DB2USER"
echo "          COPT_MART_DB2PASS="
echo "          LOCAL_HOSTNAME=$LOCAL_HOSTNAME"
echo
echo "==> The config file is located at $config_file"
echo "==> Please edit this file and fill in the correct information for the"
echo "    following tags:"
echo

if [ "$RPICOMP" = "TRUE" ]; then
    echo "    PS_HOME"
fi

echo "    DB2PASS"
echo "    COPT_CTRL_DB2PASS"
echo "    COPT_CDW_DB2PASS"
echo "    COPT_MART_DB2PASS"
echo
echo "  Once the editing is complete, rerun the setup.bat or setup.sh scripts"
echo "  that were originally run."
echo
echo "  For more information on the definition of each of these tags, please"
echo "  look at the template config file (twh_core_patcher.cfg) located in the"
echo "  'generic/install/bin' directory of this patch"
