--Update the source db to generic ODBC rather than DB2
update iwh.inforesource set dbtype='Generic ODBC' where name='CDW_TWH_CDW_Source';
update iwh.inforesource set subdbtype='User Defined ODBC' where name='CDW_TWH_CDW_Source';
update iwh.inforesource set ODBCCONNECTSTRBIN='0000000057' where name='CDW_TWH_CDW_Source';

--Update the UDPs to call bash
--update iwh.progfunc2 set programname='bash' where name in ('rollup', 'SQLScript', 'runReport');

--Update the AgentSite Source info if this is an NLS site.
create table twg.temp_eng_agent_sources (
        Relation_Name          varchar(20),
        Source_IWHID           varchar(20),
        Target_IWHID           varchar(20)
        );

insert into twg.temp_eng_agent_sources
        select Relation_Name,
               Source_IWHID,
               Target_IWHID
        from iwh.relationship
        where Source_IWHID =
              (select iwhid from iwh.agentsite where vwdefault != 1 and name = 'Default DWC AgentSite');

create table twg.temp_native_agent_sources (
        Relation_Name          varchar(20),
        Source_IWHID           varchar(20),
        Target_IWHID           varchar(20)
        );

insert into twg.temp_native_agent_sources
        select Relation_Name,
               Source_IWHID,
               Target_IWHID
        from iwh.relationship
        where Source_IWHID =
              (select iwhid from iwh.agentsite where vwdefault = 1);

create table twg.temp_common_agent_sources (
        Relation_Name          varchar(20),
        Source_IWHID           varchar(20),
        Target_IWHID           varchar(20)
        );

insert into twg.temp_common_agent_sources
        select e.Relation_Name,
               e.Source_IWHID,
               e.Target_IWHID
        from twg.temp_eng_agent_sources e,
             twg.temp_native_agent_sources n
        where e.Relation_Name = n.Relation_Name
          and e.Target_IWHID = n.Target_IWHID;

-- deletes english agent sources where a native one exists
delete from iwh.relationship where (Relation_Name, Source_IWHID, Target_IWHID) in
       (select Relation_Name, Source_IWHID, Target_IWHID from twg.temp_common_agent_sources);

-- updates any remaining english agent source records
update iwh.relationship
set source_iwhid = (select iwhid from iwh.agentsite where vwdefault = 1)
where
source_iwhid = (select iwhid from iwh.agentsite where vwdefault != 1 and name = 'Default DWC AgentSite');

-- delete the temporary tables used above
drop table twg.temp_eng_agent_sources;
drop table twg.temp_native_agent_sources;
drop table twg.temp_common_agent_sources;

--Update the AgentSite Target info if this is an NLS site.
create table twg.temp_eng_agent_targets (
        Relation_Name          varchar(20),
        Source_IWHID           varchar(20),
        Target_IWHID           varchar(20)
        );

insert into twg.temp_eng_agent_targets
        select Relation_Name,
               Source_IWHID,
               Target_IWHID
        from iwh.relationship
        where Target_IWHID =
              (select iwhid from iwh.agentsite where vwdefault != 1 and name = 'Default DWC AgentSite');

create table twg.temp_native_agent_targets (
        Relation_Name          varchar(20),
        Source_IWHID           varchar(20),
        Target_IWHID           varchar(20)
        );

insert into twg.temp_native_agent_targets
        select Relation_Name,
               Source_IWHID,
               Target_IWHID
        from iwh.relationship
        where Target_IWHID =
              (select iwhid from iwh.agentsite where vwdefault = 1);

create table twg.temp_common_agent_targets (
        Relation_Name          varchar(20),
        Source_IWHID           varchar(20),
        Target_IWHID           varchar(20)
        );

insert into twg.temp_common_agent_targets
        select e.Relation_Name,
               e.Source_IWHID,
               e.Target_IWHID
        from twg.temp_eng_agent_targets e,
             twg.temp_native_agent_targets n
        where e.Relation_Name = n.Relation_Name
          and e.Source_IWHID = n.Source_IWHID;

-- deletes english agent targets where a native one also exists
delete from iwh.relationship where (Relation_Name, Source_IWHID, Target_IWHID) in
       (select Relation_Name, Source_IWHID, Target_IWHID from twg.temp_common_agent_targets);

-- updates any remaining english target records
update iwh.relationship
set target_iwhid = (select iwhid from iwh.agentsite where vwdefault = 1)
where
target_iwhid = (select iwhid from iwh.agentsite where vwdefault != 1 and name = 'Default DWC AgentSite');

-- now we can delete the english agentsite
delete from iwh.agentsite where vwdefault != 1 and name = 'Default DWC AgentSite';

-- delete the temporary tables used above
drop table twg.temp_eng_agent_targets;
drop table twg.temp_native_agent_targets;
drop table twg.temp_common_agent_targets;

--Update the SecurityGroup Source info if this is an NLS site.
create table twg.temp_eng_secgr_sources (
        Relation_Name          varchar(20),
        Source_IWHID           varchar(20),
        Target_IWHID           varchar(20)
        );

insert into twg.temp_eng_secgr_sources
        select Relation_Name,
               Source_IWHID,
               Target_IWHID
        from iwh.relationship
        where Source_IWHID =
              (select iwhid from iwh.securitygroup where vwdefault != 1 and name = 'Default Security Group');

create table twg.temp_native_secgr_sources (
        Relation_Name          varchar(20),
        Source_IWHID           varchar(20),
        Target_IWHID           varchar(20)
        );

insert into twg.temp_native_secgr_sources
        select Relation_Name,
               Source_IWHID,
               Target_IWHID
        from iwh.relationship
        where Source_IWHID =
              (select iwhid from iwh.securitygroup where vwdefault = 1);

create table twg.temp_common_secgr_sources (
        Relation_Name          varchar(20),
        Source_IWHID           varchar(20),
        Target_IWHID           varchar(20)
        );

insert into twg.temp_common_secgr_sources
        select e.Relation_Name,
               e.Source_IWHID,
               e.Target_IWHID
        from twg.temp_eng_secgr_sources e,
             twg.temp_native_secgr_sources n
        where e.Relation_Name = n.Relation_Name
          and e.Target_IWHID = n.Target_IWHID;

-- deletes english agent sources where a native one exists
delete from iwh.relationship where (Relation_Name, Source_IWHID, Target_IWHID) in
       (select Relation_Name, Source_IWHID, Target_IWHID from twg.temp_common_secgr_sources);

-- updates any remaining english agent source records
update iwh.relationship
set source_iwhid = (select iwhid from iwh.securitygroup where vwdefault = 1)
where
source_iwhid = (select iwhid from iwh.securitygroup where vwdefault != 1 and name = 'Default Security Group');

-- delete the temporary tables used above
drop table twg.temp_eng_secgr_sources;
drop table twg.temp_native_secgr_sources;
drop table twg.temp_common_secgr_sources;

--Update the SecurityGroup Target info if this is an NLS site.
create table twg.temp_eng_secgr_targets (
        Relation_Name          varchar(20),
        Source_IWHID           varchar(20),
        Target_IWHID           varchar(20)
        );

insert into twg.temp_eng_secgr_targets
        select Relation_Name,
               Source_IWHID,
               Target_IWHID
        from iwh.relationship
        where Target_IWHID =
              (select iwhid from iwh.securitygroup where vwdefault != 1 and name = 'Default Security Group');

create table twg.temp_native_secgr_targets (
        Relation_Name          varchar(20),
        Source_IWHID           varchar(20),
        Target_IWHID           varchar(20)
        );

insert into twg.temp_native_secgr_targets
        select Relation_Name,
               Source_IWHID,
               Target_IWHID
        from iwh.relationship
        where Target_IWHID =
              (select iwhid from iwh.securitygroup where vwdefault = 1);

create table twg.temp_common_secgr_targets (
        Relation_Name          varchar(20),
        Source_IWHID           varchar(20),
        Target_IWHID           varchar(20)
        );

insert into twg.temp_common_secgr_targets
        select e.Relation_Name,
               e.Source_IWHID,
               e.Target_IWHID
        from twg.temp_eng_secgr_targets e,
             twg.temp_native_secgr_targets n
        where e.Relation_Name = n.Relation_Name
          and e.Source_IWHID = n.Source_IWHID;

-- deletes english securitygroup targets where a native one also exists
delete from iwh.relationship where (Relation_Name, Source_IWHID, Target_IWHID) in
       (select Relation_Name, Source_IWHID, Target_IWHID from twg.temp_common_secgr_targets);

-- updates any remaining english target records
update iwh.relationship
set target_iwhid = (select iwhid from iwh.securitygroup where vwdefault = 1)
where
target_iwhid = (select iwhid from iwh.securitygroup where vwdefault != 1 and name = 'Default Security Group');

-- now we can delete the english securitygroup
delete from iwh.securitygroup where vwdefault != 1 and name = 'Default Security Group';

-- delete the temporary tables used above
drop table twg.temp_eng_secgr_targets;
drop table twg.temp_native_secgr_targets;
drop table twg.temp_common_secgr_targets;

