#!/bin/sh

#-----------------------------------------------------------------------
#
# Tivoli Enterprise Data Warehouse, v 1.1.0 
# (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
#
#-----------------------------------------------------------------------
#
# File Information: src/tools/bin/sqlscript.sh, twh_core, twh_1.1_fp1
#
# Revision: 1.15
#
# Date: 6/25/02 14:06:26

# ############
# SQLScript.sh
# ############

# Wrapper for SQL script files

# Force avacode to be lower case so path names get constructed in lower case
typeset -l AVACODE

# Parameters
AVACODE="$1"
SCRIPTNAME="$2"
SRCDB="$3"
SRCUSER=$4
SRCPWD=$5
TGTDB=$6
TGTUSER=$7
TGTPWD=$8

# ava code is passed upper case from the DWC but the path is lower case
AVACODE=` echo "$1" | tr '[A-Z]' '[a-z]' `

APPDIR=` echo "$TWH_TOPDIR/apps/$AVACODE" | sed 's/\\\\/\//g' `

cmdResult=`ls -1 "$APPDIR" | grep '^v' | wc -l | sed -e 's/ *//g'`

if [ "$cmdResult" != "1" ]; then
   echo "<MSG>CDW8084E Bad directory structure. Only one directory beginning with 'v' should exist in $APPDIR </MSG>" >> "$VWP_LOG"
   echo "<RC>8084</RC>" >> "$VWP_LOG"
   exit 8084
fi

cmdResult=`ls -d "$APPDIR"/v*`
version=`basename "$cmdResult" `

FULLSCRIPT="$APPDIR/$version/etl/sql/$SCRIPTNAME"
FULLLOG="$VWS_LOGGING/$SCRIPTNAME.log"

# Run the script
execsql "$FULLSCRIPT" "$FULLLOG" "$SRCDB" "$SRCUSER" "$SRCPWD" $TGTDB $TGTUSER $TGTPWD
RC=$?

# Some interps limit the return value to one byte (small int)
# execsqls RCs are greater than 256
if [ $RC -lt 256 -a $RC -gt 0 ]; then
  EXIT_VAL=`expr $RC + 7936`
else
  EXIT_VAL=$RC
fi

exit $EXIT_VAL

